import { closeIcon } from '@genesislcap/foundation-ui';
import { sync } from '@genesislcap/foundation-utils';
import { html, ref, repeat } from '@microsoft/fast-element';
const closeIconTemplate = html `
  <div class="close-icon" @click=${(x) => x['clear']()}>${closeIcon()}</div>
`;
const textFilterTemplate = html `
  <div class="flex-row">
    <div>${(x) => x.label}</div>
    ${closeIconTemplate}
  </div>
  <div class="flex-row">
    <zero-text-field ${ref('textFilterField')} type="text" :value=${sync((x) => x.textFilter)} />
  </div>
`;
const numberFilterTemplate = html `
  <div class="flex-row">
    <div>${(x) => x.label}</div>
    ${closeIconTemplate}
  </div>
  <div class="flex-row">
    <zero-text-field
      ${ref('numFilterFieldMin')}
      type="number"
      :value=${sync((x) => x.numFilterMin)}
      placeholder="min"
    ></zero-text-field>
    <zero-text-field
      ${ref('numFilterFieldMax')}
      type="number"
      :value=${sync((x) => x.numFilterMax)}
      placeholder="max"
    ></zero-text-field>
  </div>
`;
const dateFilterTemplate = html `
  <div class="flex-row">
    <div>${(x) => x.label}</div>
    ${closeIconTemplate}
  </div>
  <div class="flex-row">
    <zero-text-field
      ${ref('dateFilterFieldMin')}
      type="date"
      :value=${sync((x) => x.dateFilterMin)}
      placeholder="min"
    ></zero-text-field>
    <zero-text-field
      ${ref('dateFilterFieldMax')}
      type="date"
      :value=${sync((x) => x.dateFilterMax)}
      placeholder="max"
    ></zero-text-field>
  </div>
`;
function targetValue(ctx) {
    var _a, _b, _c;
    return (_c = (_b = (_a = ctx === null || ctx === void 0 ? void 0 : ctx.event) === null || _a === void 0 ? void 0 : _a.target) === null || _b === void 0 ? void 0 : _b.value) !== null && _c !== void 0 ? _c : 'all';
}
const booleanFilterOptions = [
    { name: 'All', value: 'all', selected: true },
    { name: 'True', value: 'true' },
    { name: 'False', value: 'false' },
    { name: 'N/A', value: 'null' },
];
const booleanFilterTemplate = html `
  <div class="flex-row">
    <div>${(x) => x.label}</div>
    ${closeIconTemplate}
  </div>
  <div class="flex-row">
    <zero-select @change="${(x, c) => x['onBooleanFilterSelection'](targetValue(c))}}">
      ${repeat(() => booleanFilterOptions, html `
          <zero-option value="${(x) => x.value}" selected="${(x) => x.selected}">
            ${(x) => x.name}
          </zero-option>
        `)}
    </zero-select>
  </div>
`;
const enumFilterTemplate = html `
  <div class="flex-row">
    <div>${(x) => x.label}</div>
    ${closeIconTemplate}
  </div>
  <div class="flex-row">
    <zero-select @change="${(x, c) => x['onEnumFilterSelection'](targetValue(c))}}">
      ${repeat((x) => x.enumFilterOptions, html `
          <zero-option value="${(x) => x.value}" selected="${(x) => x.selected}">
            ${(x) => x.name}
          </zero-option>
        `)}
    </zero-select>
  </div>
`;
const selectTemplate = (x) => {
    switch (x.type) {
        case 'number':
            return numberFilterTemplate;
        case 'date':
            return dateFilterTemplate;
        case 'boolean':
            return booleanFilterTemplate;
        case 'enum':
            return enumFilterTemplate;
        default:
            return textFilterTemplate;
    }
};
export const zeroFilterTemplate = html `
  <div class="filter-wrapper">${(x) => selectTemplate(x)}</div>
`;
//# sourceMappingURL=filter.template.js.map